@@ -11,7 +11,7 @@ function add_key {
             echo "Failed to add Docker keyring"
             exit 1
         fi
-        # hkp://pool.sks-keyservers.net intermittenly doesnt have the correct
+        # hkp://pool.sks-keyservers.net intermittently doesn't have the correct
         # keyring. p80 is what the docker script pulls from and what we should
         # use for reliability too
         sudo apt-key adv --keyserver hkp://p80.pool.sks-keyservers.net:80 --recv-keys 58118E89F3A912897C070ADBF76221572C52609D && break || :
@@ -30,7 +30,7 @@ function setup_disk {
 
     if [ ! -f /docker ]; then
         sudo dd if=/dev/zero of=/docker bs=1M count=10240
-        losetup -f /docker
+        sudo losetup -f /docker
         DEV=$(losetup -a | awk -F: '/\/docker/ {print $1}')
     fi
 
@@ -57,12 +57,13 @@ source /etc/lsb-release
 echo "deb http://apt.dockerproject.org/repo ubuntu-${DISTRIB_CODENAME} main" | sudo tee /etc/apt/sources.list.d/docker.list
 add_key
 sudo apt-get update
-sudo apt-get -y install --no-install-recommends 'docker-engine=1.12.*' btrfs-tools
+sudo apt-get -y install --no-install-recommends 'docker-engine=1.12.*'
 
 sudo service docker stop
-setup_disk
 if [[ ${DISTRIB_CODENAME} == "trusty" ]]; then
-    echo 'DOCKER_OPTS="-s btrfs"' | sudo tee /etc/default/docker
+    sudo apt-get -y install --no-install-recommends btrfs-tools
+    setup_disk
+    echo "DOCKER_OPTS=\"-s btrfs --insecure-registry $(cat /etc/nodepool/primary_node_private):4000\"" | sudo tee /etc/default/docker
     sudo mount --make-shared /run
     sudo service docker start
 else
@@ -70,7 +71,7 @@ else
     sudo tee /etc/systemd/system/docker.service.d/kolla.conf << EOF
 [Service]
 ExecStart=
-ExecStart=/usr/bin/dockerd --storage-driver btrfs
+ExecStart=/usr/bin/dockerd --storage-driver overlay2 --insecure-registry $(cat /etc/nodepool/primary_node_private):4000
 MountFlags=shared
 EOF
     sudo systemctl daemon-reload
